FMM driver
==========

.. module:: boxtree.fmm

.. autofunction:: drive_fmm

.. autoclass:: ExpansionWranglerInterface
    :members:
    :undoc-members:
    :member-order: bysource

.. autoclass:: TimingResult

.. autoclass:: TimingFuture

Integration with PyFMMLib
-------------------------

.. automodule:: boxtree.pyfmmlib_integration

.. autoclass:: FMMLibRotationDataInterface

.. autoclass:: FMMLibRotationData

.. autoclass:: FMMLibRotationDataNotSuppliedWarning

.. autoclass:: FMMLibExpansionWrangler

.. vim: sw=4
